# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/service/parameters.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.common_config import parameters_pb2 as prodvana_dot_common__config_dot_parameters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/service/parameters.proto\x12\x10prodvana.service\x1a\'prodvana/common_config/parameters.proto\"w\n PerReleaseChannelParameterValues\x12\x17\n\x0frelease_channel\x18\x01 \x01(\t\x12:\n\nparameters\x18\x02 \x03(\x0b\x32&.prodvana.common_config.ParameterValue\"\xa5\x01\n\x16ServiceParameterValues\x12:\n\nparameters\x18\x01 \x03(\x0b\x32&.prodvana.common_config.ParameterValue\x12O\n\x13per_release_channel\x18\x02 \x03(\x0b\x32\x32.prodvana.service.PerReleaseChannelParameterValuesBLZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/serviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.service.parameters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/service'
  _globals['_PERRELEASECHANNELPARAMETERVALUES']._serialized_start=96
  _globals['_PERRELEASECHANNELPARAMETERVALUES']._serialized_end=215
  _globals['_SERVICEPARAMETERVALUES']._serialized_start=218
  _globals['_SERVICEPARAMETERVALUES']._serialized_end=383
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.auth import auth_manager_pb2 as prodvana_dot_auth_dot_auth__manager__pb2


class AuthManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAuthToken = channel.unary_unary(
                '/prodvana.auth.AuthManager/GetAuthToken',
                request_serializer=prodvana_dot_auth_dot_auth__manager__pb2.GetTokenRequest.SerializeToString,
                response_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.GetAuthTokenResp.FromString,
                )
        self.GetAuthUrl = channel.unary_unary(
                '/prodvana.auth.AuthManager/GetAuthUrl',
                request_serializer=prodvana_dot_auth_dot_auth__manager__pb2.GetAuthUrlRequest.SerializeToString,
                response_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.GetAuthUrlResponse.FromString,
                )
        self.RefreshToken = channel.unary_unary(
                '/prodvana.auth.AuthManager/RefreshToken',
                request_serializer=prodvana_dot_auth_dot_auth__manager__pb2.RefreshTokenReq.SerializeToString,
                response_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.GetAuthTokenResp.FromString,
                )
        self.CliAuth = channel.unary_stream(
                '/prodvana.auth.AuthManager/CliAuth',
                request_serializer=prodvana_dot_auth_dot_auth__manager__pb2.CliAuthReq.SerializeToString,
                response_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.CliAuthResp.FromString,
                )


class AuthManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAuthToken(self, request, context):
        """web auth flow
        TODO(naphat) we should make this only available to our UI app
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAuthUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RefreshToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CliAuth(self, request, context):
        """cli auth flow
        This returns a streaming response with exactly two items:
        1. Immediately, a UserPrmopt will be returned which should then be conveyed to the user
        2. Once user authenticates via a browser, a Token will be returned
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAuthToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAuthToken,
                    request_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.GetTokenRequest.FromString,
                    response_serializer=prodvana_dot_auth_dot_auth__manager__pb2.GetAuthTokenResp.SerializeToString,
            ),
            'GetAuthUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAuthUrl,
                    request_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.GetAuthUrlRequest.FromString,
                    response_serializer=prodvana_dot_auth_dot_auth__manager__pb2.GetAuthUrlResponse.SerializeToString,
            ),
            'RefreshToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RefreshToken,
                    request_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.RefreshTokenReq.FromString,
                    response_serializer=prodvana_dot_auth_dot_auth__manager__pb2.GetAuthTokenResp.SerializeToString,
            ),
            'CliAuth': grpc.unary_stream_rpc_method_handler(
                    servicer.CliAuth,
                    request_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.CliAuthReq.FromString,
                    response_serializer=prodvana_dot_auth_dot_auth__manager__pb2.CliAuthResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.auth.AuthManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AuthManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAuthToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.auth.AuthManager/GetAuthToken',
            prodvana_dot_auth_dot_auth__manager__pb2.GetTokenRequest.SerializeToString,
            prodvana_dot_auth_dot_auth__manager__pb2.GetAuthTokenResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAuthUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.auth.AuthManager/GetAuthUrl',
            prodvana_dot_auth_dot_auth__manager__pb2.GetAuthUrlRequest.SerializeToString,
            prodvana_dot_auth_dot_auth__manager__pb2.GetAuthUrlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RefreshToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.auth.AuthManager/RefreshToken',
            prodvana_dot_auth_dot_auth__manager__pb2.RefreshTokenReq.SerializeToString,
            prodvana_dot_auth_dot_auth__manager__pb2.GetAuthTokenResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CliAuth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/prodvana.auth.AuthManager/CliAuth',
            prodvana_dot_auth_dot_auth__manager__pb2.CliAuthReq.SerializeToString,
            prodvana_dot_auth_dot_auth__manager__pb2.CliAuthResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class AuthSessionManagerStub(object):
    """unlike AuthManager, AuthSessionManager is about the current authenticated session, i.e. it requires
    user to be authed already
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Check = channel.unary_unary(
                '/prodvana.auth.AuthSessionManager/Check',
                request_serializer=prodvana_dot_auth_dot_auth__manager__pb2.Empty.SerializeToString,
                response_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.Empty.FromString,
                )
        self.Logout = channel.unary_unary(
                '/prodvana.auth.AuthSessionManager/Logout',
                request_serializer=prodvana_dot_auth_dot_auth__manager__pb2.LogoutReq.SerializeToString,
                response_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.LogoutResp.FromString,
                )


class AuthSessionManagerServicer(object):
    """unlike AuthManager, AuthSessionManager is about the current authenticated session, i.e. it requires
    user to be authed already
    """

    def Check(self, request, context):
        """check if user is authenticated and token is still valid
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Logout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthSessionManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Check': grpc.unary_unary_rpc_method_handler(
                    servicer.Check,
                    request_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.Empty.FromString,
                    response_serializer=prodvana_dot_auth_dot_auth__manager__pb2.Empty.SerializeToString,
            ),
            'Logout': grpc.unary_unary_rpc_method_handler(
                    servicer.Logout,
                    request_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.LogoutReq.FromString,
                    response_serializer=prodvana_dot_auth_dot_auth__manager__pb2.LogoutResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.auth.AuthSessionManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AuthSessionManager(object):
    """unlike AuthManager, AuthSessionManager is about the current authenticated session, i.e. it requires
    user to be authed already
    """

    @staticmethod
    def Check(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.auth.AuthSessionManager/Check',
            prodvana_dot_auth_dot_auth__manager__pb2.Empty.SerializeToString,
            prodvana_dot_auth_dot_auth__manager__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Logout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.auth.AuthSessionManager/Logout',
            prodvana_dot_auth_dot_auth__manager__pb2.LogoutReq.SerializeToString,
            prodvana_dot_auth_dot_auth__manager__pb2.LogoutResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class ApiTokenManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateOrgApiToken = channel.unary_unary(
                '/prodvana.auth.ApiTokenManager/CreateOrgApiToken',
                request_serializer=prodvana_dot_auth_dot_auth__manager__pb2.Empty.SerializeToString,
                response_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.CreateOrgApiTokenResp.FromString,
                )
        self.CreateOrgApiToken2 = channel.unary_unary(
                '/prodvana.auth.ApiTokenManager/CreateOrgApiToken2',
                request_serializer=prodvana_dot_auth_dot_auth__manager__pb2.CreateOrgApiTokenReq.SerializeToString,
                response_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.CreateOrgApiTokenResp.FromString,
                )
        self.DeleteOrgApiToken = channel.unary_unary(
                '/prodvana.auth.ApiTokenManager/DeleteOrgApiToken',
                request_serializer=prodvana_dot_auth_dot_auth__manager__pb2.DeleteOrgApiTokenReq.SerializeToString,
                response_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.DeleteOrgApiTokenResp.FromString,
                )
        self.ListOrgApiTokens = channel.unary_unary(
                '/prodvana.auth.ApiTokenManager/ListOrgApiTokens',
                request_serializer=prodvana_dot_auth_dot_auth__manager__pb2.ListOrgApiTokensReq.SerializeToString,
                response_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.ListOrgApiTokensResp.FromString,
                )


class ApiTokenManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateOrgApiToken(self, request, context):
        """Create an api token tied to the organization. This api token is not tied to the user in anyway,
        e.g. if the user is deleted, the token will continue to have access to the organization.
        This token currently does not expire, so be very careful with storing them.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrgApiToken2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrgApiToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrgApiTokens(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ApiTokenManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateOrgApiToken': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrgApiToken,
                    request_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.Empty.FromString,
                    response_serializer=prodvana_dot_auth_dot_auth__manager__pb2.CreateOrgApiTokenResp.SerializeToString,
            ),
            'CreateOrgApiToken2': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrgApiToken2,
                    request_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.CreateOrgApiTokenReq.FromString,
                    response_serializer=prodvana_dot_auth_dot_auth__manager__pb2.CreateOrgApiTokenResp.SerializeToString,
            ),
            'DeleteOrgApiToken': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrgApiToken,
                    request_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.DeleteOrgApiTokenReq.FromString,
                    response_serializer=prodvana_dot_auth_dot_auth__manager__pb2.DeleteOrgApiTokenResp.SerializeToString,
            ),
            'ListOrgApiTokens': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrgApiTokens,
                    request_deserializer=prodvana_dot_auth_dot_auth__manager__pb2.ListOrgApiTokensReq.FromString,
                    response_serializer=prodvana_dot_auth_dot_auth__manager__pb2.ListOrgApiTokensResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.auth.ApiTokenManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ApiTokenManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateOrgApiToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.auth.ApiTokenManager/CreateOrgApiToken',
            prodvana_dot_auth_dot_auth__manager__pb2.Empty.SerializeToString,
            prodvana_dot_auth_dot_auth__manager__pb2.CreateOrgApiTokenResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrgApiToken2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.auth.ApiTokenManager/CreateOrgApiToken2',
            prodvana_dot_auth_dot_auth__manager__pb2.CreateOrgApiTokenReq.SerializeToString,
            prodvana_dot_auth_dot_auth__manager__pb2.CreateOrgApiTokenResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrgApiToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.auth.ApiTokenManager/DeleteOrgApiToken',
            prodvana_dot_auth_dot_auth__manager__pb2.DeleteOrgApiTokenReq.SerializeToString,
            prodvana_dot_auth_dot_auth__manager__pb2.DeleteOrgApiTokenResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrgApiTokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.auth.ApiTokenManager/ListOrgApiTokens',
            prodvana_dot_auth_dot_auth__manager__pb2.ListOrgApiTokensReq.SerializeToString,
            prodvana_dot_auth_dot_auth__manager__pb2.ListOrgApiTokensResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/constants.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&prodvana/common_config/constants.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\"p\n\x08\x43onstant\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x38\n\x06string\x18\x03 \x01(\x0b\x32&.prodvana.common_config.StringConstantH\x00\x42\x13\n\x0c\x63onfig_oneof\x12\x03\xf8\x42\x01\"\x1f\n\x0eStringConstant\x12\r\n\x05value\x18\x01 \x01(\tBRZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.constants_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _CONSTANT.oneofs_by_name['config_oneof']._options = None
  _CONSTANT.oneofs_by_name['config_oneof']._serialized_options = b'\370B\001'
  _CONSTANT.fields_by_name['name']._options = None
  _CONSTANT.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CONSTANT']._serialized_start=91
  _globals['_CONSTANT']._serialized_end=203
  _globals['_STRINGCONSTANT']._serialized_start=205
  _globals['_STRINGCONSTANT']._serialized_end=236
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/events/events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.events import types_pb2 as prodvana_dot_events_dot_types__pb2
from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cprodvana/events/events.proto\x12\x0fprodvana.events\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bprodvana/events/types.proto\x1a&prodvana/version/source_metadata.proto\"\xd7\x02\n\x05\x45vent\x12\n\n\x02id\x18\x01 \x01(\t\x12(\n\x04type\x18\x02 \x01(\x0e\x32\x1a.prodvana.events.EventType\x12\r\n\x05title\x18\x03 \x01(\t\x12.\n\x07\x64\x65tails\x18\x04 \x01(\x0b\x32\x1d.prodvana.events.EventDetails\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x0frelated_objects\x18\x06 \x01(\x0b\x32\x1f.prodvana.events.RelatedObjects\x12(\n\x06source\x18\x08 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\t \x01(\x0b\x32 .prodvana.version.SourceMetadataJ\x04\x08\x07\x10\x08R\x05\x61\x63tor\"\xb8\x02\n\x0eRelatedObjects\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x1a\n\x12release_channel_id\x18\x03 \x01(\t\x12\x18\n\x10\x64\x65sired_state_id\x18\x04 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\x05 \x01(\t\x12\x12\n\nrelease_id\x18\x08 \x01(\t\x12\x12\n\nruntime_id\x18\x06 \x01(\t\x12H\n\rexternal_logs\x18\x07 \x03(\x0b\x32\x31.prodvana.events.RelatedObjects.ExternalLogsEntry\x1a\x33\n\x11\x45xternalLogsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42KZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/eventsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.events.events_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/events'
  _RELATEDOBJECTS_EXTERNALLOGSENTRY._options = None
  _RELATEDOBJECTS_EXTERNALLOGSENTRY._serialized_options = b'8\001'
  _globals['_EVENT']._serialized_start=152
  _globals['_EVENT']._serialized_end=495
  _globals['_RELATEDOBJECTS']._serialized_start=498
  _globals['_RELATEDOBJECTS']._serialized_end=810
  _globals['_RELATEDOBJECTS_EXTERNALLOGSENTRY']._serialized_start=759
  _globals['_RELATEDOBJECTS_EXTERNALLOGSENTRY']._serialized_end=810
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/settings/organization/users.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.users import users_pb2 as prodvana_dot_users_dot_users__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*prodvana/settings/organization/users.proto\x12\x1eprodvana.settings.organization\x1a\x1cgoogle/api/annotations.proto\x1a\x1aprodvana/users/users.proto\"A\n\x0cSettingsUser\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.prodvana.users.User\x12\r\n\x05roles\x18\x02 \x03(\t\"\x1d\n\nGetUserReq\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"I\n\x0bGetUserResp\x12:\n\x04user\x18\x01 \x01(\x0b\x32,.prodvana.settings.organization.SettingsUser\"\x0e\n\x0cListRolesReq\"3\n\x0eRoleDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"N\n\rListRolesResp\x12=\n\x05roles\x18\x01 \x03(\x0b\x32..prodvana.settings.organization.RoleDefinition\"5\n\x0cListUsersReq\x12\x12\n\npage_token\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\"e\n\rListUsersResp\x12;\n\x05users\x18\x01 \x03(\x0b\x32,.prodvana.settings.organization.SettingsUser\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"-\n\x0bSetRolesReq\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\r\n\x05roles\x18\x02 \x03(\t\"\x0e\n\x0cSetRolesResp\"*\n\nUserInvite\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\r\n\x05roles\x18\x02 \x03(\t\"K\n\x0eInviteUsersReq\x12\x39\n\x05users\x18\x01 \x03(\x0b\x32*.prodvana.settings.organization.UserInvite\"\x11\n\x0fInviteUsersResp\" \n\x1eOrganizationSupportsInvitesReq\";\n\x1fOrganizationSupportsInvitesResp\x12\x18\n\x10supports_invites\x18\x01 \x01(\x08\" \n\rRemoveUserReq\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"\x10\n\x0eRemoveUserResp2\x91\t\n\x14UsersSettingsManager\x12\x95\x01\n\x07GetUser\x12*.prodvana.settings.organization.GetUserReq\x1a+.prodvana.settings.organization.GetUserResp\"1\x82\xd3\xe4\x93\x02+\x12)/v1/settings/organization/users/{user_id}\x12\x91\x01\n\tListUsers\x12,.prodvana.settings.organization.ListUsersReq\x1a-.prodvana.settings.organization.ListUsersResp\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/settings/organization/users\x12\x91\x01\n\tListRoles\x12,.prodvana.settings.organization.ListRolesReq\x1a-.prodvana.settings.organization.ListRolesResp\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/settings/organization/roles\x12\x9e\x01\n\x08SetRoles\x12+.prodvana.settings.organization.SetRolesReq\x1a,.prodvana.settings.organization.SetRolesResp\"7\x82\xd3\xe4\x93\x02\x31\"//v1/settings/organization/users/{user_id}/roles\x12\xa1\x01\n\x0bInviteUsers\x12..prodvana.settings.organization.InviteUsersReq\x1a/.prodvana.settings.organization.InviteUsersResp\"1\x82\xd3\xe4\x93\x02+\"&/v1/settings/organization/users/invite:\x01*\x12\xd2\x01\n\x1bOrganizationSupportsInvites\x12>.prodvana.settings.organization.OrganizationSupportsInvitesReq\x1a?.prodvana.settings.organization.OrganizationSupportsInvitesResp\"2\x82\xd3\xe4\x93\x02,\x12*/v1/settings/organization/users/can_invite\x12\x9e\x01\n\nRemoveUser\x12-.prodvana.settings.organization.RemoveUserReq\x1a..prodvana.settings.organization.RemoveUserResp\"1\x82\xd3\xe4\x93\x02+*)/v1/settings/organization/users/{user_id}BZZXgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/settings/organizationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.settings.organization.users_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZXgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/settings/organization'
  _USERSSETTINGSMANAGER.methods_by_name['GetUser']._options = None
  _USERSSETTINGSMANAGER.methods_by_name['GetUser']._serialized_options = b'\202\323\344\223\002+\022)/v1/settings/organization/users/{user_id}'
  _USERSSETTINGSMANAGER.methods_by_name['ListUsers']._options = None
  _USERSSETTINGSMANAGER.methods_by_name['ListUsers']._serialized_options = b'\202\323\344\223\002!\022\037/v1/settings/organization/users'
  _USERSSETTINGSMANAGER.methods_by_name['ListRoles']._options = None
  _USERSSETTINGSMANAGER.methods_by_name['ListRoles']._serialized_options = b'\202\323\344\223\002!\022\037/v1/settings/organization/roles'
  _USERSSETTINGSMANAGER.methods_by_name['SetRoles']._options = None
  _USERSSETTINGSMANAGER.methods_by_name['SetRoles']._serialized_options = b'\202\323\344\223\0021\"//v1/settings/organization/users/{user_id}/roles'
  _USERSSETTINGSMANAGER.methods_by_name['InviteUsers']._options = None
  _USERSSETTINGSMANAGER.methods_by_name['InviteUsers']._serialized_options = b'\202\323\344\223\002+\"&/v1/settings/organization/users/invite:\001*'
  _USERSSETTINGSMANAGER.methods_by_name['OrganizationSupportsInvites']._options = None
  _USERSSETTINGSMANAGER.methods_by_name['OrganizationSupportsInvites']._serialized_options = b'\202\323\344\223\002,\022*/v1/settings/organization/users/can_invite'
  _USERSSETTINGSMANAGER.methods_by_name['RemoveUser']._options = None
  _USERSSETTINGSMANAGER.methods_by_name['RemoveUser']._serialized_options = b'\202\323\344\223\002+*)/v1/settings/organization/users/{user_id}'
  _globals['_SETTINGSUSER']._serialized_start=136
  _globals['_SETTINGSUSER']._serialized_end=201
  _globals['_GETUSERREQ']._serialized_start=203
  _globals['_GETUSERREQ']._serialized_end=232
  _globals['_GETUSERRESP']._serialized_start=234
  _globals['_GETUSERRESP']._serialized_end=307
  _globals['_LISTROLESREQ']._serialized_start=309
  _globals['_LISTROLESREQ']._serialized_end=323
  _globals['_ROLEDEFINITION']._serialized_start=325
  _globals['_ROLEDEFINITION']._serialized_end=376
  _globals['_LISTROLESRESP']._serialized_start=378
  _globals['_LISTROLESRESP']._serialized_end=456
  _globals['_LISTUSERSREQ']._serialized_start=458
  _globals['_LISTUSERSREQ']._serialized_end=511
  _globals['_LISTUSERSRESP']._serialized_start=513
  _globals['_LISTUSERSRESP']._serialized_end=614
  _globals['_SETROLESREQ']._serialized_start=616
  _globals['_SETROLESREQ']._serialized_end=661
  _globals['_SETROLESRESP']._serialized_start=663
  _globals['_SETROLESRESP']._serialized_end=677
  _globals['_USERINVITE']._serialized_start=679
  _globals['_USERINVITE']._serialized_end=721
  _globals['_INVITEUSERSREQ']._serialized_start=723
  _globals['_INVITEUSERSREQ']._serialized_end=798
  _globals['_INVITEUSERSRESP']._serialized_start=800
  _globals['_INVITEUSERSRESP']._serialized_end=817
  _globals['_ORGANIZATIONSUPPORTSINVITESREQ']._serialized_start=819
  _globals['_ORGANIZATIONSUPPORTSINVITESREQ']._serialized_end=851
  _globals['_ORGANIZATIONSUPPORTSINVITESRESP']._serialized_start=853
  _globals['_ORGANIZATIONSUPPORTSINVITESRESP']._serialized_end=912
  _globals['_REMOVEUSERREQ']._serialized_start=914
  _globals['_REMOVEUSERREQ']._serialized_end=946
  _globals['_REMOVEUSERRESP']._serialized_start=948
  _globals['_REMOVEUSERRESP']._serialized_end=964
  _globals['_USERSSETTINGSMANAGER']._serialized_start=967
  _globals['_USERSSETTINGSMANAGER']._serialized_end=2136
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class LocalConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    PATHS_FIELD_NUMBER: builtins.int
    SUB_PATH_FIELD_NUMBER: builtins.int
    EXCLUDE_PATTERNS_FIELD_NUMBER: builtins.int
    path: builtins.str
    """Specify a path to a local file or directory"""
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """cannot be set in conjunction with path or tarball_blob_id
        Specify multiple paths. They will get concatenated.
        """
    sub_path: builtins.str
    """A sub_path relative to path containing the actual config.
    sub_path value can be templated, e.g. `{{.Builtins.ReleaseChannel.Name}}`.
    if specified, path must also be specified and be a directory.
    """
    @property
    def exclude_patterns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Used in conjunction with sub_path to exclude sub paths from being tarball'ed and uploaded
        to Prodvana.
        Follows the same format as gitignore.
        """
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        paths: collections.abc.Iterable[builtins.str] | None = ...,
        sub_path: builtins.str = ...,
        exclude_patterns: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["path", b"path", "path_oneof", b"path_oneof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exclude_patterns", b"exclude_patterns", "path", b"path", "path_oneof", b"path_oneof", "paths", b"paths", "sub_path", b"sub_path"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["path_oneof", b"path_oneof"]) -> typing_extensions.Literal["path"] | None: ...

global___LocalConfig = LocalConfig

class RemoteConfig(google.protobuf.message.Message):
    """a remote config, specified by a remote source and a subpath"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARBALL_BLOB_ID_FIELD_NUMBER: builtins.int
    SUB_PATH_FIELD_NUMBER: builtins.int
    tarball_blob_id: builtins.str
    """A directory tarball blob id uploaded to prodvana.proto.prodvana.
    TODO(naphat) git repo support?
    """
    sub_path: builtins.str
    def __init__(
        self,
        *,
        tarball_blob_id: builtins.str = ...,
        sub_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["remote_oneof", b"remote_oneof", "tarball_blob_id", b"tarball_blob_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["remote_oneof", b"remote_oneof", "sub_path", b"sub_path", "tarball_blob_id", b"tarball_blob_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["remote_oneof", b"remote_oneof"]) -> typing_extensions.Literal["tarball_blob_id"] | None: ...

global___RemoteConfig = RemoteConfig

class KubernetesConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[KubernetesConfig._Type.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: KubernetesConfig._Type.ValueType  # 0
        KUBERNETES: KubernetesConfig._Type.ValueType  # 1
        KUSTOMIZE: KubernetesConfig._Type.ValueType  # 2

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    UNKNOWN: KubernetesConfig.Type.ValueType  # 0
    KUBERNETES: KubernetesConfig.Type.ValueType  # 1
    KUSTOMIZE: KubernetesConfig.Type.ValueType  # 2

    class _EnvInjectionMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EnvInjectionModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[KubernetesConfig._EnvInjectionMode.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ENV_INJECT_UNKNOWN: KubernetesConfig._EnvInjectionMode.ValueType  # 0
        ENV_INJECT_DISABLED: KubernetesConfig._EnvInjectionMode.ValueType  # 1
        """disables env injection entirely"""
        ENV_INJECT_NON_SECRET_ENV: KubernetesConfig._EnvInjectionMode.ValueType  # 2
        """inject non-secret env values from the Release Channel"""

    class EnvInjectionMode(_EnvInjectionMode, metaclass=_EnvInjectionModeEnumTypeWrapper): ...
    ENV_INJECT_UNKNOWN: KubernetesConfig.EnvInjectionMode.ValueType  # 0
    ENV_INJECT_DISABLED: KubernetesConfig.EnvInjectionMode.ValueType  # 1
    """disables env injection entirely"""
    ENV_INJECT_NON_SECRET_ENV: KubernetesConfig.EnvInjectionMode.ValueType  # 2
    """inject non-secret env values from the Release Channel"""

    TYPE_FIELD_NUMBER: builtins.int
    INLINED_FIELD_NUMBER: builtins.int
    LOCAL_FIELD_NUMBER: builtins.int
    REMOTE_FIELD_NUMBER: builtins.int
    ENV_INJECTION_MODE_FIELD_NUMBER: builtins.int
    PATCHES_FIELD_NUMBER: builtins.int
    type: global___KubernetesConfig.Type.ValueType
    inlined: builtins.str
    @property
    def local(self) -> global___LocalConfig: ...
    @property
    def remote(self) -> global___RemoteConfig: ...
    env_injection_mode: global___KubernetesConfig.EnvInjectionMode.ValueType
    """Defaults to ENV_INJECT_NON_SECRET_ENV"""
    @property
    def patches(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___KubernetesPatch]: ...
    def __init__(
        self,
        *,
        type: global___KubernetesConfig.Type.ValueType = ...,
        inlined: builtins.str = ...,
        local: global___LocalConfig | None = ...,
        remote: global___RemoteConfig | None = ...,
        env_injection_mode: global___KubernetesConfig.EnvInjectionMode.ValueType = ...,
        patches: collections.abc.Iterable[global___KubernetesPatch] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["inlined", b"inlined", "local", b"local", "remote", b"remote", "source_oneof", b"source_oneof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["env_injection_mode", b"env_injection_mode", "inlined", b"inlined", "local", b"local", "patches", b"patches", "remote", b"remote", "source_oneof", b"source_oneof", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["source_oneof", b"source_oneof"]) -> typing_extensions.Literal["inlined", "local", "remote"] | None: ...

global___KubernetesConfig = KubernetesConfig

class KubernetesPatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Target(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        GROUP_FIELD_NUMBER: builtins.int
        VERSION_FIELD_NUMBER: builtins.int
        KIND_FIELD_NUMBER: builtins.int
        NAME_FIELD_NUMBER: builtins.int
        NAMESPACE_FIELD_NUMBER: builtins.int
        group: builtins.str
        """omit any of these fields to match all values"""
        version: builtins.str
        kind: builtins.str
        name: builtins.str
        namespace: builtins.str
        def __init__(
            self,
            *,
            group: builtins.str = ...,
            version: builtins.str = ...,
            kind: builtins.str = ...,
            name: builtins.str = ...,
            namespace: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["group", b"group", "kind", b"kind", "name", b"name", "namespace", b"namespace", "version", b"version"]) -> None: ...

    class Replace(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PATH_FIELD_NUMBER: builtins.int
        STRING_FIELD_NUMBER: builtins.int
        INT_AS_STRING_FIELD_NUMBER: builtins.int
        path: builtins.str
        """json6902 path"""
        string: builtins.str
        int_as_string: builtins.str
        def __init__(
            self,
            *,
            path: builtins.str = ...,
            string: builtins.str = ...,
            int_as_string: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["int_as_string", b"int_as_string", "string", b"string", "value_oneof", b"value_oneof"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["int_as_string", b"int_as_string", "path", b"path", "string", b"string", "value_oneof", b"value_oneof"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["value_oneof", b"value_oneof"]) -> typing_extensions.Literal["string", "int_as_string"] | None: ...

    TARGET_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    @property
    def target(self) -> global___KubernetesPatch.Target:
        """filter to a specific Kubernetes object. Omit to apply to all objects."""
    @property
    def replace(self) -> global___KubernetesPatch.Replace: ...
    def __init__(
        self,
        *,
        target: global___KubernetesPatch.Target | None = ...,
        replace: global___KubernetesPatch.Replace | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["patch_oneof", b"patch_oneof", "replace", b"replace", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["patch_oneof", b"patch_oneof", "replace", b"replace", "target", b"target"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["patch_oneof", b"patch_oneof"]) -> typing_extensions.Literal["replace"] | None: ...

global___KubernetesPatch = KubernetesPatch



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/events/events_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.events import events_pb2 as prodvana_dot_events_dot_events__pb2
from prodvana.proto.prodvana.events import types_pb2 as prodvana_dot_events_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$prodvana/events/events_manager.proto\x12\x0fprodvana.events\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\x1a\x1cprodvana/events/events.proto\x1a\x1bprodvana/events/types.proto\"G\n\rServiceLookup\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"V\n\x14ReleaseChannelLookup\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12 \n\x0frelease_channel\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xf6\x01\n\x06Lookup\x12\x1f\n\x15root_desired_state_id\x18\x01 \x01(\tH\x00\x12\x1a\n\x10\x64\x65sired_state_id\x18\x03 \x01(\tH\x00\x12\x31\n\x07service\x18\x04 \x01(\x0b\x32\x1e.prodvana.events.ServiceLookupH\x00\x12@\n\x0frelease_channel\x18\x05 \x01(\x0b\x32%.prodvana.events.ReleaseChannelLookupH\x00\x12\x14\n\nrelease_id\x18\x06 \x01(\tH\x00\x42\x13\n\x0clookup_oneof\x12\x03\xf8\x42\x01J\x04\x08\x02\x10\x03R\tentity_id\"\xf0\x02\n\x0cGetEventsReq\x12\x39\n\x07lookups\x18\x01 \x03(\x0b\x32\x17.prodvana.events.LookupB\x0f\xfa\x42\x0c\x92\x01\t\x08\x01\"\x05\x8a\x01\x02\x10\x01\x12)\n\x05types\x18\x02 \x03(\x0e\x32\x1a.prodvana.events.EventType\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x1e\n\x16order_by_asc_timestamp\x18\x06 \x01(\x08\x12\r\n\x05useOr\x18\x07 \x01(\x08\x12\x34\n\x10\x62\x65\x66ore_timestamp\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x61\x66ter_timestamp\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12\x65xpand_for_release\x18\n \x01(\x08J\x04\x08\x05\x10\x06R\x17order_by_desc_timestamp\"P\n\rGetEventsResp\x12&\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x16.prodvana.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2r\n\rEventsManager\x12\x61\n\tGetEvents\x12\x1d.prodvana.events.GetEventsReq\x1a\x1e.prodvana.events.GetEventsResp\"\x15\x82\xd3\xe4\x93\x02\x0f\"\n/v1/events:\x01*BKZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/eventsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.events.events_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/events'
  _SERVICELOOKUP.fields_by_name['application']._options = None
  _SERVICELOOKUP.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _SERVICELOOKUP.fields_by_name['service']._options = None
  _SERVICELOOKUP.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASECHANNELLOOKUP.fields_by_name['application']._options = None
  _RELEASECHANNELLOOKUP.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASECHANNELLOOKUP.fields_by_name['release_channel']._options = None
  _RELEASECHANNELLOOKUP.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _LOOKUP.oneofs_by_name['lookup_oneof']._options = None
  _LOOKUP.oneofs_by_name['lookup_oneof']._serialized_options = b'\370B\001'
  _GETEVENTSREQ.fields_by_name['lookups']._options = None
  _GETEVENTSREQ.fields_by_name['lookups']._serialized_options = b'\372B\014\222\001\t\010\001\"\005\212\001\002\020\001'
  _EVENTSMANAGER.methods_by_name['GetEvents']._options = None
  _EVENTSMANAGER.methods_by_name['GetEvents']._serialized_options = b'\202\323\344\223\002\017\"\n/v1/events:\001*'
  _globals['_SERVICELOOKUP']._serialized_start=204
  _globals['_SERVICELOOKUP']._serialized_end=275
  _globals['_RELEASECHANNELLOOKUP']._serialized_start=277
  _globals['_RELEASECHANNELLOOKUP']._serialized_end=363
  _globals['_LOOKUP']._serialized_start=366
  _globals['_LOOKUP']._serialized_end=612
  _globals['_GETEVENTSREQ']._serialized_start=615
  _globals['_GETEVENTSREQ']._serialized_end=983
  _globals['_GETEVENTSRESP']._serialized_start=985
  _globals['_GETEVENTSRESP']._serialized_end=1065
  _globals['_EVENTSMANAGER']._serialized_start=1067
  _globals['_EVENTSMANAGER']._serialized_end=1181
# @@protoc_insertion_point(module_scope)



from typing import Iterable, Optional, Sequence, Tuple

from prodvana.proto.prodvana.common_config.parameters_pb2 import (
    ParameterDefinition,
    ParameterValue,
)


def make_default_value(param_def: ParameterDefinition) -> Optional[ParameterValue]:
    val = ParameterValue(name=param_def.name)
    if param_def.int:
        val.int = param_def.int.default_value
    elif param_def.string:
        val.string = param_def.string.default_value
    elif param_def.docker_image:
        val.docker_image_tag = param_def.docker_image.default_tag
    elif param_def.secret:
        return None  # no valid default value
    elif param_def.commit:
        return None  # no valid default value
    else:
        raise Exception(f"Unknown parameter definition: {param_def}")
    return val


def get_parameter_values(
    defs: Sequence[ParameterDefinition], values: Sequence[ParameterValue]
) -> Iterable[Tuple[ParameterDefinition, ParameterValue]]:
    """
    Given a list of parameter definitions and values, return a tuple of definitions with their values,
    where if no explicit value is provided, the default is used.

    If the parameter is required but no value is provided, that parameter is skipped (this is an invalid state).
    """
    val_by_name = {v.name: v for v in values}
    for param_def in defs:
        val = val_by_name.get(param_def.name)
        if not val:
            val = make_default_value(param_def)
        if not val:
            continue
        yield (param_def, val)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.async_task.task_metadata_pb2
import prodvana.proto.prodvana.desired_state.maestro.maestro_pb2
import prodvana.proto.prodvana.desired_state.model.desired_state_pb2
import prodvana.proto.prodvana.desired_state.model.entity_pb2
import prodvana.proto.prodvana.service.service_config_pb2
import prodvana.proto.prodvana.version.source_metadata_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SetDesiredStateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_FIELD_NUMBER: builtins.int
    ROLLBACK_FIELD_NUMBER: builtins.int
    BYPASS_PRECONDITIONS_AND_PROTECTIONS_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    FORCE_ASYNC_SET_DESIRED_STATE_FIELD_NUMBER: builtins.int
    MAESTRO_CONFIG_OVERRIDE_FIELD_NUMBER: builtins.int
    @property
    def desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    rollback: builtins.bool
    """set if this is a rollback, purely for metadata purposes."""
    bypass_preconditions_and_protections: builtins.bool
    """generate a desired state with faster preconditions"""
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    force_async_set_desired_state: builtins.bool
    """internal use only"""
    @property
    def maestro_config_override(self) -> prodvana.proto.prodvana.desired_state.maestro.maestro_pb2.MaestroConfig:
        """optionally override maestro config for this service"""
    def __init__(
        self,
        *,
        desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        rollback: builtins.bool = ...,
        bypass_preconditions_and_protections: builtins.bool = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
        force_async_set_desired_state: builtins.bool = ...,
        maestro_config_override: prodvana.proto.prodvana.desired_state.maestro.maestro_pb2.MaestroConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["desired_state", b"desired_state", "maestro_config_override", b"maestro_config_override", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bypass_preconditions_and_protections", b"bypass_preconditions_and_protections", "desired_state", b"desired_state", "force_async_set_desired_state", b"force_async_set_desired_state", "maestro_config_override", b"maestro_config_override", "rollback", b"rollback", "source", b"source", "source_metadata", b"source_metadata"]) -> None: ...

global___SetDesiredStateReq = SetDesiredStateReq

class ValidateDesiredStateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_FIELD_NUMBER: builtins.int
    ROLLBACK_FIELD_NUMBER: builtins.int
    BYPASS_PRECONDITIONS_AND_PROTECTIONS_FIELD_NUMBER: builtins.int
    SERVICE_INSTANCE_CONFIGS_FIELD_NUMBER: builtins.int
    LABEL_EXPANSION_ONLY_FIELD_NUMBER: builtins.int
    DISREGARD_SERVICE_VERSIONS_FIELD_NUMBER: builtins.int
    @property
    def desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    rollback: builtins.bool
    """set if this is a rollback, purely for metadata purposes"""
    bypass_preconditions_and_protections: builtins.bool
    """generate a desired state with faster preconditions"""
    @property
    def service_instance_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.service.service_config_pb2.CompiledServiceInstanceConfig]:
        """optional, if set, use these service configs instead of fetching from db. can be useful when doing a ValidateApplyParameters followed by a ValidateDesiredState"""
    label_expansion_only: builtins.bool
    """only do label expansion instead of the full compilation, can be useful for speedup if the only desired outcome is to look at the materialized release channels"""
    disregard_service_versions: builtins.bool
    """assume service versions in the request are invalid and do not try to fetch them."""
    def __init__(
        self,
        *,
        desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        rollback: builtins.bool = ...,
        bypass_preconditions_and_protections: builtins.bool = ...,
        service_instance_configs: collections.abc.Iterable[prodvana.proto.prodvana.service.service_config_pb2.CompiledServiceInstanceConfig] | None = ...,
        label_expansion_only: builtins.bool = ...,
        disregard_service_versions: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["desired_state", b"desired_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bypass_preconditions_and_protections", b"bypass_preconditions_and_protections", "desired_state", b"desired_state", "disregard_service_versions", b"disregard_service_versions", "label_expansion_only", b"label_expansion_only", "rollback", b"rollback", "service_instance_configs", b"service_instance_configs"]) -> None: ...

global___ValidateDesiredStateReq = ValidateDesiredStateReq

class SetDesiredStateResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    RELEASE_ID_FIELD_NUMBER: builtins.int
    desired_state_id: builtins.str
    """unique identifier for the desired state that was just set, unless maestro is used"""
    release_id: builtins.str
    """release ID for maestro. If this is set, desired_state_id will not be set"""
    def __init__(
        self,
        *,
        desired_state_id: builtins.str = ...,
        release_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id", "id_oneof", b"id_oneof", "release_id", b"release_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id", "id_oneof", b"id_oneof", "release_id", b"release_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["id_oneof", b"id_oneof"]) -> typing_extensions.Literal["desired_state_id", "release_id"] | None: ...

global___SetDesiredStateResp = SetDesiredStateResp

class PreviewEntityGraphResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_GRAPH_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    @property
    def entity_graph(self) -> prodvana.proto.prodvana.desired_state.model.entity_pb2.EntityGraph: ...
    desired_state_id: builtins.str
    """unique identifier the preview entity graph that was just created. This same ID can be used across any endpoints that inspect desired states, e.g. GetDesiredState"""
    def __init__(
        self,
        *,
        entity_graph: prodvana.proto.prodvana.desired_state.model.entity_pb2.EntityGraph | None = ...,
        desired_state_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity_graph", b"entity_graph"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id", "entity_graph", b"entity_graph"]) -> None: ...

global___PreviewEntityGraphResp = PreviewEntityGraphResp

class GetServiceDesiredStateConvergenceSummaryReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    FAST_NO_DEPRECATED_FIELDS_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    fast_no_deprecated_fields: builtins.bool
    """unused"""
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        fast_no_deprecated_fields: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "fast_no_deprecated_fields", b"fast_no_deprecated_fields", "service", b"service"]) -> None: ...

global___GetServiceDesiredStateConvergenceSummaryReq = GetServiceDesiredStateConvergenceSummaryReq

class StatusExplanations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_EXPLANATIONS_FIELD_NUMBER: builtins.int
    @property
    def status_explanations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation]: ...
    def __init__(
        self,
        *,
        status_explanations: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status_explanations", b"status_explanations"]) -> None: ...

global___StatusExplanations = StatusExplanations

class DebugLogs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEBUG_LOGS_FIELD_NUMBER: builtins.int
    @property
    def debug_logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DebugLog]: ...
    def __init__(
        self,
        *,
        debug_logs: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DebugLog] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["debug_logs", b"debug_logs"]) -> None: ...

global___DebugLogs = DebugLogs

class PendingSetDesiredState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    COMPILED_DESIRED_STATE_FIELD_NUMBER: builtins.int
    TASK_STATUS_FIELD_NUMBER: builtins.int
    TASK_RESULT_FIELD_NUMBER: builtins.int
    desired_state_id: builtins.str
    @property
    def compiled_desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    task_status: prodvana.proto.prodvana.async_task.task_metadata_pb2.TaskStatus.ValueType
    """will never contain SUCCESS, by definition, but may contain FAILED"""
    @property
    def task_result(self) -> prodvana.proto.prodvana.async_task.task_metadata_pb2.TaskResult:
        """will only be set for FAILED
        next tag: 5
        """
    def __init__(
        self,
        *,
        desired_state_id: builtins.str = ...,
        compiled_desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        task_status: prodvana.proto.prodvana.async_task.task_metadata_pb2.TaskStatus.ValueType = ...,
        task_result: prodvana.proto.prodvana.async_task.task_metadata_pb2.TaskResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_desired_state", b"compiled_desired_state", "task_result", b"task_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_desired_state", b"compiled_desired_state", "desired_state_id", b"desired_state_id", "task_result", b"task_result", "task_status", b"task_status"]) -> None: ...

global___PendingSetDesiredState = PendingSetDesiredState

class DesiredStateSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class StatusesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class PreconditionStatusesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConditionState: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConditionState | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class StatusExplanationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___StatusExplanations: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___StatusExplanations | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class DebugLogsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___DebugLogs: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___DebugLogs | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class ActionExplanationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ActionExplanation: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ActionExplanation | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class LastUpdateTimestampsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class LastFetchedTimestampsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class LastAppliedTimestampsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENTITY_GRAPH_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_UPDATE_TIMESTAMP_FIELD_NUMBER: builtins.int
    REPLACED_TIMESTAMP_FIELD_NUMBER: builtins.int
    INPUT_DESIRED_STATE_FIELD_NUMBER: builtins.int
    DESIRED_STATE_FIELD_NUMBER: builtins.int
    STARTING_STATE_FIELD_NUMBER: builtins.int
    LAST_SEEN_STATE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    PENDING_SET_DESIRED_STATE_FIELD_NUMBER: builtins.int
    SET_DESIRED_STATE_METADATA_FIELD_NUMBER: builtins.int
    STATUSES_FIELD_NUMBER: builtins.int
    PRECONDITION_STATUSES_FIELD_NUMBER: builtins.int
    STATUS_EXPLANATIONS_FIELD_NUMBER: builtins.int
    DEBUG_LOGS_FIELD_NUMBER: builtins.int
    ACTION_EXPLANATIONS_FIELD_NUMBER: builtins.int
    LAST_UPDATE_TIMESTAMPS_FIELD_NUMBER: builtins.int
    LAST_FETCHED_TIMESTAMPS_FIELD_NUMBER: builtins.int
    LAST_APPLIED_TIMESTAMPS_FIELD_NUMBER: builtins.int
    @property
    def entity_graph(self) -> prodvana.proto.prodvana.desired_state.model.entity_pb2.EntityGraph: ...
    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_update_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def replaced_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """will only be set if desired state has been replaced"""
    @property
    def input_desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """uncompiled desired state originally passed as input to SetDesiredState"""
    @property
    def desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """compiled desired state"""
    @property
    def starting_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def last_seen_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    """who set the desired state"""
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    @property
    def pending_set_desired_state(self) -> global___PendingSetDesiredState:
        """the latest pending or failed set desired state request"""
    @property
    def set_desired_state_metadata(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.SetDesiredStateMetadata: ...
    @property
    def statuses(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType]:
        """fields below are deprecated
        status of the desired state, all its descendents, and the root desired state.
        """
    @property
    def precondition_statuses(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConditionState]:
        """State of all preconditions involved in the desired state.
        Key format - "{desired_state_id}-{index}", e.g., "des-0752d6c76a6943abbfcf0515634584ba-0".
        """
    @property
    def status_explanations(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___StatusExplanations]: ...
    @property
    def debug_logs(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___DebugLogs]: ...
    @property
    def action_explanations(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ActionExplanation]: ...
    @property
    def last_update_timestamps(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, google.protobuf.timestamp_pb2.Timestamp]:
        """last_update_timestamp, last_fetched_timestamp, and last_applied_timestamp are only returned for the latest desired state"""
    @property
    def last_fetched_timestamps(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, google.protobuf.timestamp_pb2.Timestamp]: ...
    @property
    def last_applied_timestamps(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, google.protobuf.timestamp_pb2.Timestamp]: ...
    def __init__(
        self,
        *,
        entity_graph: prodvana.proto.prodvana.desired_state.model.entity_pb2.EntityGraph | None = ...,
        creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_update_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        replaced_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        input_desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        starting_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        last_seen_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
        pending_set_desired_state: global___PendingSetDesiredState | None = ...,
        set_desired_state_metadata: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.SetDesiredStateMetadata | None = ...,
        statuses: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType] | None = ...,
        precondition_statuses: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConditionState] | None = ...,
        status_explanations: collections.abc.Mapping[builtins.str, global___StatusExplanations] | None = ...,
        debug_logs: collections.abc.Mapping[builtins.str, global___DebugLogs] | None = ...,
        action_explanations: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ActionExplanation] | None = ...,
        last_update_timestamps: collections.abc.Mapping[builtins.str, google.protobuf.timestamp_pb2.Timestamp] | None = ...,
        last_fetched_timestamps: collections.abc.Mapping[builtins.str, google.protobuf.timestamp_pb2.Timestamp] | None = ...,
        last_applied_timestamps: collections.abc.Mapping[builtins.str, google.protobuf.timestamp_pb2.Timestamp] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "desired_state", b"desired_state", "entity_graph", b"entity_graph", "input_desired_state", b"input_desired_state", "last_seen_state", b"last_seen_state", "last_update_timestamp", b"last_update_timestamp", "pending_set_desired_state", b"pending_set_desired_state", "replaced_timestamp", b"replaced_timestamp", "set_desired_state_metadata", b"set_desired_state_metadata", "source_metadata", b"source_metadata", "starting_state", b"starting_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_explanations", b"action_explanations", "creation_timestamp", b"creation_timestamp", "debug_logs", b"debug_logs", "desired_state", b"desired_state", "entity_graph", b"entity_graph", "input_desired_state", b"input_desired_state", "last_applied_timestamps", b"last_applied_timestamps", "last_fetched_timestamps", b"last_fetched_timestamps", "last_seen_state", b"last_seen_state", "last_update_timestamp", b"last_update_timestamp", "last_update_timestamps", b"last_update_timestamps", "pending_set_desired_state", b"pending_set_desired_state", "precondition_statuses", b"precondition_statuses", "replaced_timestamp", b"replaced_timestamp", "set_desired_state_metadata", b"set_desired_state_metadata", "source", b"source", "source_metadata", b"source_metadata", "starting_state", b"starting_state", "status", b"status", "status_explanations", b"status_explanations", "statuses", b"statuses"]) -> None: ...

global___DesiredStateSummary = DesiredStateSummary

class GetDesiredStateConvergenceReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    FAST_NO_DEPRECATED_FIELDS_FIELD_NUMBER: builtins.int
    desired_state_id: builtins.str
    fast_no_deprecated_fields: builtins.bool
    """unused"""
    def __init__(
        self,
        *,
        desired_state_id: builtins.str = ...,
        fast_no_deprecated_fields: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id", "fast_no_deprecated_fields", b"fast_no_deprecated_fields"]) -> None: ...

global___GetDesiredStateConvergenceReq = GetDesiredStateConvergenceReq

class GetDesiredStateConvergenceSummaryResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUMMARY_FIELD_NUMBER: builtins.int
    @property
    def summary(self) -> global___DesiredStateSummary: ...
    def __init__(
        self,
        *,
        summary: global___DesiredStateSummary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["summary", b"summary"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["summary", b"summary"]) -> None: ...

global___GetDesiredStateConvergenceSummaryResp = GetDesiredStateConvergenceSummaryResp

class GetServiceDesiredStateConvergenceSummaryResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUMMARY_FIELD_NUMBER: builtins.int
    @property
    def summary(self) -> global___DesiredStateSummary: ...
    def __init__(
        self,
        *,
        summary: global___DesiredStateSummary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["summary", b"summary"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["summary", b"summary"]) -> None: ...

global___GetServiceDesiredStateConvergenceSummaryResp = GetServiceDesiredStateConvergenceSummaryResp

class GetServiceLastConvergedStateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "service", b"service"]) -> None: ...

global___GetServiceLastConvergedStateReq = GetServiceLastConvergedStateReq

class GetServiceLastConvergedStateResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_INSTANCE_STATES_FIELD_NUMBER: builtins.int
    @property
    def service_instance_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ServiceInstanceState]: ...
    def __init__(
        self,
        *,
        service_instance_states: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ServiceInstanceState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["service_instance_states", b"service_instance_states"]) -> None: ...

global___GetServiceLastConvergedStateResp = GetServiceLastConvergedStateResp

class GetServiceDesiredStateHistoryReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    FAST_NO_DEPRECATED_FIELDS_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    page_token: builtins.str
    page_size: builtins.int
    fast_no_deprecated_fields: builtins.bool
    """unused"""
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
        fast_no_deprecated_fields: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "fast_no_deprecated_fields", b"fast_no_deprecated_fields", "page_size", b"page_size", "page_token", b"page_token", "service", b"service"]) -> None: ...

global___GetServiceDesiredStateHistoryReq = GetServiceDesiredStateHistoryReq

class GetServiceDesiredStateHistoryResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def desired_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DesiredStateSummary]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        desired_states: collections.abc.Iterable[global___DesiredStateSummary] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_states", b"desired_states", "next_page_token", b"next_page_token"]) -> None: ...

global___GetServiceDesiredStateHistoryResp = GetServiceDesiredStateHistoryResp

class GetDesiredStateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    desired_state_id: builtins.str
    def __init__(
        self,
        *,
        desired_state_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id"]) -> None: ...

global___GetDesiredStateReq = GetDesiredStateReq

class GetDesiredStateResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_FIELD_NUMBER: builtins.int
    COMPILED_DESIRED_STATE_FIELD_NUMBER: builtins.int
    SET_DESIRED_STATE_METADATA_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    @property
    def desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def compiled_desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def set_desired_state_metadata(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.SetDesiredStateMetadata: ...
    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    """who set the desired state"""
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    def __init__(
        self,
        *,
        desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        compiled_desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        set_desired_state_metadata: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.SetDesiredStateMetadata | None = ...,
        creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_desired_state", b"compiled_desired_state", "creation_timestamp", b"creation_timestamp", "desired_state", b"desired_state", "set_desired_state_metadata", b"set_desired_state_metadata", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_desired_state", b"compiled_desired_state", "creation_timestamp", b"creation_timestamp", "desired_state", b"desired_state", "set_desired_state_metadata", b"set_desired_state_metadata", "source", b"source", "source_metadata", b"source_metadata"]) -> None: ...

global___GetDesiredStateResp = GetDesiredStateResp

class GetDesiredStateGraphReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class QueryByService(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        APPLICATION_FIELD_NUMBER: builtins.int
        SERVICE_FIELD_NUMBER: builtins.int
        application: builtins.str
        service: builtins.str
        def __init__(
            self,
            *,
            application: builtins.str = ...,
            service: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "service", b"service"]) -> None: ...

    class DepthOverrideByStatus(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STATUS_FIELD_NUMBER: builtins.int
        DEPTH_FIELD_NUMBER: builtins.int
        status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
        depth: builtins.int
        def __init__(
            self,
            *,
            status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
            depth: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["depth", b"depth", "status", b"status"]) -> None: ...

    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    QUERY_BY_SERVICE_FIELD_NUMBER: builtins.int
    TYPES_FIELD_NUMBER: builtins.int
    REQUIRED_ANNOTATIONS_FIELD_NUMBER: builtins.int
    REQUIRED_ENTITY_NAMES_FIELD_NUMBER: builtins.int
    DEPTH_FIELD_NUMBER: builtins.int
    DEPTH_OVERRIDES_BY_STATUS_FIELD_NUMBER: builtins.int
    INCLUDE_DESIRED_STATE_TIMESTAMPS_FIELD_NUMBER: builtins.int
    desired_state_id: builtins.str
    @property
    def query_by_service(self) -> global___GetDesiredStateGraphReq.QueryByService: ...
    @property
    def types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Type.ValueType]:
        """Find interesting entities in the graph.
        Which entities are interesting is defined by the type and required_annotations fields.

        Which type of entities to find. Empty list to find all entities.
        """
    @property
    def required_annotations(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Annotations:
        """Which annotations are required for an entity to be considered interesting."""
    @property
    def required_entity_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    depth: builtins.int
    """For all interesting entities, also include all children up to the given depth. 0 means no children."""
    @property
    def depth_overrides_by_status(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetDesiredStateGraphReq.DepthOverrideByStatus]: ...
    include_desired_state_timestamps: builtins.bool
    def __init__(
        self,
        *,
        desired_state_id: builtins.str = ...,
        query_by_service: global___GetDesiredStateGraphReq.QueryByService | None = ...,
        types: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Type.ValueType] | None = ...,
        required_annotations: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Annotations | None = ...,
        required_entity_names: collections.abc.Iterable[builtins.str] | None = ...,
        depth: builtins.int = ...,
        depth_overrides_by_status: collections.abc.Iterable[global___GetDesiredStateGraphReq.DepthOverrideByStatus] | None = ...,
        include_desired_state_timestamps: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id", "query", b"query", "query_by_service", b"query_by_service", "required_annotations", b"required_annotations"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["depth", b"depth", "depth_overrides_by_status", b"depth_overrides_by_status", "desired_state_id", b"desired_state_id", "include_desired_state_timestamps", b"include_desired_state_timestamps", "query", b"query", "query_by_service", b"query_by_service", "required_annotations", b"required_annotations", "required_entity_names", b"required_entity_names", "types", b"types"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["query", b"query"]) -> typing_extensions.Literal["desired_state_id", "query_by_service"] | None: ...

global___GetDesiredStateGraphReq = GetDesiredStateGraphReq

class DesiredStateTimestamps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_UPDATE_TIMESTAMP_FIELD_NUMBER: builtins.int
    REPLACED_TIMESTAMP_FIELD_NUMBER: builtins.int
    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_update_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def replaced_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """will only be set if desired state has been replaced"""
    def __init__(
        self,
        *,
        creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_update_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        replaced_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "last_update_timestamp", b"last_update_timestamp", "replaced_timestamp", b"replaced_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "last_update_timestamp", b"last_update_timestamp", "replaced_timestamp", b"replaced_timestamp"]) -> None: ...

global___DesiredStateTimestamps = DesiredStateTimestamps

class GetDesiredStateGraphResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_GRAPH_FIELD_NUMBER: builtins.int
    PENDING_SET_DESIRED_STATE_FIELD_NUMBER: builtins.int
    TIMESTAMPS_FIELD_NUMBER: builtins.int
    @property
    def entity_graph(self) -> prodvana.proto.prodvana.desired_state.model.entity_pb2.EntityGraph: ...
    @property
    def pending_set_desired_state(self) -> global___PendingSetDesiredState:
        """will only be set if DS was queried by service and there is a pending set desired state"""
    @property
    def timestamps(self) -> global___DesiredStateTimestamps: ...
    def __init__(
        self,
        *,
        entity_graph: prodvana.proto.prodvana.desired_state.model.entity_pb2.EntityGraph | None = ...,
        pending_set_desired_state: global___PendingSetDesiredState | None = ...,
        timestamps: global___DesiredStateTimestamps | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity_graph", b"entity_graph", "pending_set_desired_state", b"pending_set_desired_state", "timestamps", b"timestamps"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_graph", b"entity_graph", "pending_set_desired_state", b"pending_set_desired_state", "timestamps", b"timestamps"]) -> None: ...

global___GetDesiredStateGraphResp = GetDesiredStateGraphResp

class GetServiceLatestDesiredStateIdReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "service", b"service"]) -> None: ...

global___GetServiceLatestDesiredStateIdReq = GetServiceLatestDesiredStateIdReq

class GetServiceLatestDesiredStateIdResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    PENDING_SET_DESIRED_STATE_FIELD_NUMBER: builtins.int
    desired_state_id: builtins.str
    @property
    def pending_set_desired_state(self) -> global___PendingSetDesiredState: ...
    def __init__(
        self,
        *,
        desired_state_id: builtins.str = ...,
        pending_set_desired_state: global___PendingSetDesiredState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pending_set_desired_state", b"pending_set_desired_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id", "pending_set_desired_state", b"pending_set_desired_state"]) -> None: ...

global___GetServiceLatestDesiredStateIdResp = GetServiceLatestDesiredStateIdResp

class GetServiceDesiredStateIdHistoryReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "page_size", b"page_size", "page_token", b"page_token", "service", b"service"]) -> None: ...

global___GetServiceDesiredStateIdHistoryReq = GetServiceDesiredStateIdHistoryReq

class GetServiceDesiredStateIdHistoryResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_IDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def desired_state_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        desired_state_ids: collections.abc.Iterable[builtins.str] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state_ids", b"desired_state_ids", "next_page_token", b"next_page_token"]) -> None: ...

global___GetServiceDesiredStateIdHistoryResp = GetServiceDesiredStateIdHistoryResp

class ValidateDesiredStateResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_FIELD_NUMBER: builtins.int
    COMPILED_DESIRED_STATE_FIELD_NUMBER: builtins.int
    @property
    def desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def compiled_desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    def __init__(
        self,
        *,
        desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        compiled_desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_desired_state", b"compiled_desired_state", "desired_state", b"desired_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_desired_state", b"compiled_desired_state", "desired_state", b"desired_state"]) -> None: ...

global___ValidateDesiredStateResp = ValidateDesiredStateResp

class SetManualApprovalReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    REJECT_FIELD_NUMBER: builtins.int
    SIGNAL_TYPE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    desired_state_id: builtins.str
    topic: builtins.str
    """string application = 2 [(prodvana.proto.validate.rules).string.min_len = 1];
    string service = 3 [(prodvana.proto.validate.rules).string.min_len = 1];
    string release_channel = 4 [(prodvana.proto.validate.rules).string.min_len = 1];
    """
    reject: builtins.bool
    signal_type: builtins.str
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    def __init__(
        self,
        *,
        desired_state_id: builtins.str = ...,
        topic: builtins.str = ...,
        reject: builtins.bool = ...,
        signal_type: builtins.str = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id", "reject", b"reject", "signal_type", b"signal_type", "source", b"source", "source_metadata", b"source_metadata", "topic", b"topic"]) -> None: ...

global___SetManualApprovalReq = SetManualApprovalReq

class SetManualApprovalResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetManualApprovalResp = SetManualApprovalResp

class PromoteDeliveryReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    FULL_FIELD_NUMBER: builtins.int
    REJECT_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    CALL_SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    desired_state_id: builtins.str
    stage: builtins.int
    full: builtins.bool
    reject: builtins.bool
    source: builtins.str
    call_source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    def __init__(
        self,
        *,
        desired_state_id: builtins.str = ...,
        stage: builtins.int = ...,
        full: builtins.bool = ...,
        reject: builtins.bool = ...,
        source: builtins.str = ...,
        call_source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_source", b"call_source", "desired_state_id", b"desired_state_id", "full", b"full", "reject", b"reject", "source", b"source", "source_metadata", b"source_metadata", "stage", b"stage"]) -> None: ...

global___PromoteDeliveryReq = PromoteDeliveryReq

class PromoteDeliveryResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PromoteDeliveryResp = PromoteDeliveryResp

class BypassProtectionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    CALL_SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    desired_state_id: builtins.str
    source: builtins.str
    call_source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    def __init__(
        self,
        *,
        desired_state_id: builtins.str = ...,
        source: builtins.str = ...,
        call_source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["call_source", b"call_source", "desired_state_id", b"desired_state_id", "source", b"source", "source_metadata", b"source_metadata"]) -> None: ...

global___BypassProtectionReq = BypassProtectionReq

class BypassProtectionResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___BypassProtectionResp = BypassProtectionResp

class ListMaestroReleasesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_ID_FIELD_NUMBER: builtins.int
    DESCENDING_FIELD_NUMBER: builtins.int
    STARTING_RELEASE_ID_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    @property
    def entity_id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    descending: builtins.bool
    starting_release_id: builtins.str
    """optional, if not set:
    - with descending=false, return releases starting from the oldest unfinished release.
    - with descending=true, return releases starting from the newest release.
    inclusive
    """
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        entity_id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        descending: builtins.bool = ...,
        starting_release_id: builtins.str = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity_id", b"entity_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["descending", b"descending", "entity_id", b"entity_id", "page_size", b"page_size", "page_token", b"page_token", "starting_release_id", b"starting_release_id"]) -> None: ...

global___ListMaestroReleasesReq = ListMaestroReleasesReq

class ListMaestroReleasesResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAESTRO_RELEASES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def maestro_releases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.maestro.maestro_pb2.MaestroRelease]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        maestro_releases: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.maestro.maestro_pb2.MaestroRelease] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["maestro_releases", b"maestro_releases", "next_page_token", b"next_page_token"]) -> None: ...

global___ListMaestroReleasesResp = ListMaestroReleasesResp

class GetMaestroReleaseReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_ID_FIELD_NUMBER: builtins.int
    release_id: builtins.str
    def __init__(
        self,
        *,
        release_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["release_id", b"release_id"]) -> None: ...

global___GetMaestroReleaseReq = GetMaestroReleaseReq

class GetMaestroReleaseResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAESTRO_RELEASE_FIELD_NUMBER: builtins.int
    @property
    def maestro_release(self) -> prodvana.proto.prodvana.desired_state.maestro.maestro_pb2.MaestroRelease: ...
    def __init__(
        self,
        *,
        maestro_release: prodvana.proto.prodvana.desired_state.maestro.maestro_pb2.MaestroRelease | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["maestro_release", b"maestro_release"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["maestro_release", b"maestro_release"]) -> None: ...

global___GetMaestroReleaseResp = GetMaestroReleaseResp

class ListCombinedReleasesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_ID_FIELD_NUMBER: builtins.int
    DESCENDING_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    @property
    def entity_id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    descending: builtins.bool
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        entity_id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        descending: builtins.bool = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity_id", b"entity_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["descending", b"descending", "entity_id", b"entity_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListCombinedReleasesReq = ListCombinedReleasesReq

class ListServiceCombinedReleasesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    DESCENDING_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    descending: builtins.bool
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        descending: builtins.bool = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "descending", b"descending", "page_size", b"page_size", "page_token", b"page_token", "service", b"service"]) -> None: ...

global___ListServiceCombinedReleasesReq = ListServiceCombinedReleasesReq

class ListCombinedReleasesResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Release(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
        RELEASE_ID_FIELD_NUMBER: builtins.int
        CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
        desired_state_id: builtins.str
        release_id: builtins.str
        @property
        def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            desired_state_id: builtins.str = ...,
            release_id: builtins.str = ...,
            creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "desired_state_id", b"desired_state_id", "release_id", b"release_id", "release_oneof", b"release_oneof"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "desired_state_id", b"desired_state_id", "release_id", b"release_id", "release_oneof", b"release_oneof"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["release_oneof", b"release_oneof"]) -> typing_extensions.Literal["desired_state_id", "release_id"] | None: ...

    RELEASES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def releases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListCombinedReleasesResp.Release]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        releases: collections.abc.Iterable[global___ListCombinedReleasesResp.Release] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "releases", b"releases"]) -> None: ...

global___ListCombinedReleasesResp = ListCombinedReleasesResp

class GetLatestCombinedReleaseDesiredStateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_ID_FIELD_NUMBER: builtins.int
    @property
    def entity_id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    def __init__(
        self,
        *,
        entity_id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity_id", b"entity_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_id", b"entity_id"]) -> None: ...

global___GetLatestCombinedReleaseDesiredStateReq = GetLatestCombinedReleaseDesiredStateReq

class GetServiceLatestCombinedReleaseDesiredStateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "service", b"service"]) -> None: ...

global___GetServiceLatestCombinedReleaseDesiredStateReq = GetServiceLatestCombinedReleaseDesiredStateReq

class GetLatestCombinedReleaseDesiredStateResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_DESIRED_STATE_FIELD_NUMBER: builtins.int
    COMPILED_DESIRED_STATE_FIELD_NUMBER: builtins.int
    SET_DESIRED_STATE_METADATA_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    @property
    def input_desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def compiled_desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def set_desired_state_metadata(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.SetDesiredStateMetadata: ...
    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    """who set the desired state"""
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    def __init__(
        self,
        *,
        input_desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        compiled_desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        set_desired_state_metadata: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.SetDesiredStateMetadata | None = ...,
        creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_desired_state", b"compiled_desired_state", "creation_timestamp", b"creation_timestamp", "input_desired_state", b"input_desired_state", "set_desired_state_metadata", b"set_desired_state_metadata", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_desired_state", b"compiled_desired_state", "creation_timestamp", b"creation_timestamp", "input_desired_state", b"input_desired_state", "set_desired_state_metadata", b"set_desired_state_metadata", "source", b"source", "source_metadata", b"source_metadata"]) -> None: ...

global___GetLatestCombinedReleaseDesiredStateResp = GetLatestCombinedReleaseDesiredStateResp
